import { Construct } from 'constructs';
import { StringMap, RunConfig, DefaultsConfig } from './types';
import { Workflow } from './workflow';
/**
 * Credentials to connect to a Docker registry with.
 */
export interface CredentialsConfig {
    /**
     * Username to connect with.
     */
    readonly username: string;
    /**
     * Password to connect with.
     */
    readonly password: string;
}
/**
 * Generic Docker configuration.
 */
export interface DockerConfig {
    /**
     * Image to use.
     */
    readonly image: string;
    /**
     * Credential configuration.
     */
    readonly credentials?: CredentialsConfig;
    /**
     * Additional environment variables.
     */
    readonly env?: StringMap;
    /**
     * Ports to map.
     */
    readonly ports?: string[];
    /**
     * Volumes to map.
     */
    readonly volumes?: string[];
    /**
     * Additional Docker options.
     */
    readonly options?: string;
}
/**
 * Configuration for a single GitHub Action step.
 */
export interface StepsConfig extends RunConfig {
    /**
     * A unique identifier.
     */
    readonly id?: string;
    /**
     * When to run this step.
     */
    readonly if?: string;
    /**
     * A name to display when running this action.
     */
    readonly name?: string;
    /**
     * Use an external action.
     */
    readonly uses?: string;
    /**
     * Commands to run.
     */
    readonly run?: string;
    /**
     * A map of parameters for an external action.
     */
    readonly with?: StringMap;
    /**
     * Additional environment variables.
     */
    readonly env?: StringMap;
    /**
     * Continue job if step fails.
     */
    readonly continueOnError?: boolean;
    /**
     * Maximum time before killing the step.
     */
    readonly timeoutMinutes?: number;
}
/**
 * Strategy configuration block.
 */
export interface StrategyConfig {
    /**
     * A matrix to run jobs on.
     */
    readonly matrix?: {
        [key: string]: Array<any>;
    };
    /**
     * Stop jobs when a single job fails.
     */
    readonly fastFail?: boolean;
    /**
     * Maximum parallel jobs.
     */
    readonly maxParallel?: number;
}
/**
 * Configuration for a single GitHub Action job.
 */
export interface JobConfig {
    /**
     * Displayed name of the job.
     */
    readonly name?: string;
    /**
     * A job or list of jobs that must successfully complete before running this one.
     */
    readonly needs?: string | string[];
    /**
     * The type of machine to run on.
     */
    readonly runsOn: string;
    /**
     * A map of outputs for this job.
     */
    readonly outputs?: StringMap;
    /**
     * A map of environment variables to provide to the job.
     */
    readonly env?: StringMap;
    /**
     * A map of default settings to apply to all steps in this job.
     */
    readonly defaults?: DefaultsConfig;
    /**
     * When to run this job.
     */
    readonly if?: string;
    /**
     * A list of steps to run.
     */
    readonly steps: StepsConfig[];
    /**
     * Maximum time before killing the job.
     */
    readonly timeoutMinutes?: number;
    /**
     * A strategy configuration block.
     */
    readonly strategy?: StrategyConfig;
    /**
     * Continue workflow if job fails.
     */
    readonly continueOnError?: boolean;
    /**
     * A container to run the job in.
     */
    readonly container?: DockerConfig;
    /**
     * Additional Docker services provided to the job.
     */
    readonly services?: {
        [key: string]: DockerConfig;
    };
}
/**
 * Represents a GH Actions job.
 */
export declare class Job extends Construct {
    /**
     * An internal representation of a GH Action job
     */
    private readonly action;
    /**
     * A unique identifier.
     */
    readonly id: string;
    /**
     * Defines a GitHub Actions job.
     *
     * @param scope Workflow to run within.
     * @param id A unique identifier.
     * @param config The configuration of the job.
     */
    constructor(scope: Workflow, id: string, config: JobConfig);
    /**
     * Converts the job's configuration into a format that is GitHub Actions compatible.
     */
    toGHAction(): any;
}
